dnl ***************************************************************************
dnl
dnl	$Id: aclocal.m4,v 1.1 2025/01/26 02:31:28 warme Exp $
dnl
dnl	File:	aclocal.m4
dnl	Rev:	a-1
dnl	Date:	01/25/2025
dnl
dnl	Copyright (c) 2012, 2025 by David M. Warme.  All rights
dnl	reserved.  This work is licensed under a Creative Commons
dnl	Attribution-NonCommercial-ShareAlike 4.0 International License.
dnl
dnl ***************************************************************************
dnl
dnl	Autoconf macros for indicators software bundle.
dnl
dnl ***************************************************************************
dnl
dnl	Modification Log:
dnl
dnl	a-1:	01/25/2025	warme
dnl		: Cleanup for initial release.
dnl
dnl ***************************************************************************

dnl----------------------------------------------------------------------
dnl  GMP
dnl----------------------------------------------------------------------
AC_DEFUN(AC_GMP,
[dnl set up to use GMP
if test -z "$GMP_LIBS"
then
	AC_TRY_CPP([#include <gmp.h>],
	[# We can compile using <gmp.h> with no special include dir.
	GMP_LIBS=-lgmp
	])
fi
AC_MSG_NOTICE([GMP_LIBS=$GMP_LIBS])
AC_SUBST(GMP_LIBS)
])

dnl----------------------------------------------------------------------
dnl  MPFR
dnl----------------------------------------------------------------------
AC_DEFUN(AC_MPFR,
[dnl set up to use MPFR
if test -z "$MPFR_LIBS"
then
	AC_TRY_CPP([#include <mpfr.h>],
	[# We can compile using <mpfr.h> with no special include dir.
	MPFR_LIBS=-lmpfr
	])
fi
AC_MSG_NOTICE([MPFR_LIBS=$MPFR_LIBS])
AC_SUBST(MPFR_LIBS)
])


dnl AC_DEFINE_EXPAND_VALUE(VARIABLE [, VALUE])
AC_DEFUN(AC_DEFINE_EXPAND_VALUE,
[dnl call AC_DEFINE after expanding given value
ac_expand_text1=""
ac_expand_text2="`eval echo \"$2\"`"
while test "$ac_expand_text1" != "$ac_expand_text2"
do
	ac_expand_text3="`eval echo \"$ac_expand_text2\"`"
	ac_expand_text1="$ac_expand_text2"
	ac_expand_text2="$ac_expand_text3"
done
AC_DEFINE_UNQUOTED([$1], "$ac_expand_text1")
])

dnl AC_FIND_FILE(VARIABLE, FILENAME, TESTFLAG, DIRS)
AC_DEFUN(AC_FIND_FILE,
[dnl loop over the dirs, until found
  $1=''
  for cv_ff_dir in $4
  do
        if test "$3" "$cv_ff_dir/$2"
        then
                $1="$cv_ff_dir/$2"
                break
        fi
  done
])

dnl AC_CHECK_WERROR
AC_DEFUN(AC_CHECK_WERROR,
[dnl
WERROR_FLAG=''
AC_ARG_ENABLE([Werror],
	    [--enable-Werror - Enable -Werror.],
[if test "${enableval}" != "yes"
 then
   AC_MSG_ERROR([--enable-Werror does not accept =value.])
 fi
 WERROR_FLAG='-Werror'
])
AC_SUBST(WERROR_FLAG)
])

dnl
dnl AC_IS_CPLEX_AVAILABLE
dnl
dnl This sets ac_cv_cplex_is_available to either 'yes' or 'no'.
dnl Also sets up all of the defines and substs needed to use cplex.
dnl
AC_DEFUN(AC_IS_CPLEX_AVAILABLE,
[dnl

 AC_CACHE_CHECK(if CPLEX is available,
		ac_cv_cplex_is_available,
	[dnl
	# Override the cached CPLEX settings if environment vars are set.
	ac_cv_cplex_header=''
	if test -n "$CPLEX_HEADER"
	then
		if test ! -r "$CPLEX_HEADER"
		then
			AC_MSG_ERROR(File given by \$CPLEX_HEADER unreadable!)
		fi
		ac_cv_cplex_header="$CPLEX_HEADER"
	fi
	ac_cv_cplex_lib=''
	if test -n "$CPLEX_LIB"
	then
		if test ! -r "$CPLEX_LIB"
		then
			AC_MSG_ERROR(File given by \$CPLEX_LIB unreadable!)
		fi
		ac_cv_cplex_lib="$CPLEX_LIB"
	fi

	if test -z "$ac_cv_cplex_header" || test -z "$ac_cv_cplex_lib"
	then
		# User hasn't told us where to find CPLEX header and lib.

		# Look for the cplex command in the path.  The header and
		# library are often in the same directory as the executable.
		AC_PATH_PROG(ac_cv_path_cplex, cplex)
		cplex_dir='.'
		if test -n "$ac_cv_path_cplex"
		then
			[cplex_dir="`echo $ac_cv_path_cplex | sed 's%/[^/]*$%%'`"]
		fi

		cpx_hdr_dirs="$cplex_dir /usr/include /usr/local/include"
		cpx_lib_dirs="$cplex_dir /usr/lib /usr/lib64 /usr/ccs/lib /usr/ccs/lib64 /usr/local/lib /usr/local/lib64"

		# Look for cplex.h
		AC_CACHE_CHECK(for cplex.h, ac_cv_cplex_header,
		  AC_FIND_FILE(ac_cv_cplex_header, cplex.h, -r, $cpx_hdr_dirs)
		)

		# Look for libcplex.a
		AC_CACHE_CHECK(for libcplex.a, ac_cv_cplex_lib,
		  AC_FIND_FILE(ac_cv_cplex_lib, libcplex.a, -r, $cpx_lib_dirs)
		)
	fi

	# We assume at this point, the variables ac_cv_cplex_header and
	# ac_cv_cplex_lib have been set to the absolute pathnames of the
	# appropriate files, if they are available.
	ac_cv_cplex_is_available='no'
	if test -n "$ac_cv_cplex_header" && test -n "$ac_cv_cplex_lib"
	then
		ac_cv_cplex_is_available='yes'

		# Now that we know CPLEX is available, gather other
		# information about it that is needed (if we actuall
		# use CPLEX).

		[cpxhdrdir="`echo $ac_cv_cplex_header | sed 's%/[^/]*$%%'`"]
		[cpxlibdir="`echo $ac_cv_cplex_lib | sed 's%/[^/]*$%%'`"]

		LP_PKG=cplex
		LP_CPLEX_HEADER_DIR="${cpxhdrdir}"
		LP_CPLEX_CFLAGS='-I$(LP_CPLEX_HEADER_DIR)'
		LP_CPLEX_LIB="${cpxlibdir}/libcplex.a"
		LP_CPLEX_LIB_DIR="${cpxlibdir}"
	fi
 ])

 # Modern cplex always needs -lpthread.
 LP_CPLEX_EXTRA_LIBS="-lpthread"

 AC_SUBST(LP_CPLEX_HEADER_DIR)
 AC_SUBST(LP_CPLEX_CFLAGS)
 AC_SUBST(LP_CPLEX_LIB)
 AC_SUBST(LP_CPLEX_EXTRA_LIBS)
 AC_SUBST(LP_CPLEX_LIB_DIR)
])
