/***********************************************************************

	File:	bitmaskmacros.h
	Rev:	a-2
	Date:	01/25/2025

	Copyright (c) 1997, 2025 by David M. Warme

************************************************************************

	Macros for efficient manipulation of bit masks.

************************************************************************

	Modification Log:

	a-1:	09/07/2015	warme
		: Created.
	a-2:	01/25/2025	warme
		: Cleanup for initial release.

************************************************************************/

#ifndef	BITMASKMACROS_H
#define	BITMASKMACROS_H

#include "s3itypes.h"

/*
 * Bit Maps
 */

typedef	int32u		bitmap_t;	/* Element of Bit-map vector. */
#define	BPW		32		/* Bits per word of a bit-map. */
#define	BMAP_ELTS(n)	(((n) + (BPW-1)) / BPW)

#define	SETBIT(bm, n)	((bm) [(n) / BPW] |= (1ul << ((n) % BPW)))
#define	CLRBIT(bm, n)	((bm) [(n) / BPW] &= ~(1ul << ((n) % BPW)))
#define	BITON(bm, n)	(((bm) [(n) / BPW] & (1ul << ((n) % BPW))) NE 0)

/*
 * Count the number of 1-bits in the given bitmap_t word.
 *
 * This makes use of the auxilliary `nbits' table, which must be
 * initialized (if you use this macro).
 */

#define	NBITSON(m)	(  nbits [ (m)        & 0xFFlu]		\
			 + nbits [((m) >>  8) & 0xFFlu]		\
			 + nbits [((m) >> 16) & 0xFFlu]		\
			 + nbits [((m) >> 24) & 0xFFlu])

extern int8u	nbits [];

extern void	init_nbits (void);

#endif
