/**********************************************************************

	$Id: gmpmisc.h,v 1.1 2025/01/26 02:31:38 warme Exp $

	File:	gmpmisc.h
	Rev:	a-1
	Date:	01/25/2025

	Copyright (c) 2012, 2025 by David M. Warme.  All rights
	reserved.  This work is licensed under a Creative Commons
	Attribution-NonCommercial-ShareAlike 4.0 International License.

***********************************************************************

	Miscellaneous extensions and utilities for GMP.

***********************************************************************

	Modification Log:

	a-1:	01/25/2025	warme
		: Cleanup for initial release.

***********************************************************************/

#ifndef GMPMISC_H
#define GMPMISC_H

#include <gmp.h>
#include <stddef.h>

/* Functions we wish were in GMP. */
extern void	_mpq_set_z_z (mpq_ptr		rop,
			      mpz_srcptr	op1,
			      mpz_srcptr	op2);
extern void	_mpq_div_si (mpq_ptr		rop,
			     mpq_srcptr		op1,
			     long int		op2);
extern void	_mpq_div_z (mpq_ptr		rop,
			    mpq_srcptr		op1,
			    mpz_srcptr		op2);
extern void	_mpq_mul_si (mpq_ptr		rop,
			     mpq_srcptr		op1,
			     long int		op2);
extern void	_mpq_mul_z (mpq_ptr		rop,
			    mpq_srcptr		op1,
			    mpz_srcptr		op2);

/* Routines for allocating/freeing GMP vectors (Z and Q). */
extern void	clear_Q_vector (mpq_ptr p, size_t n);
extern void	clear_Z_vector (mpz_ptr p, size_t n);
extern void	copy_Q_vector (mpq_ptr dst, mpq_srcptr src, size_t n);
extern void	copy_Z_vector (mpz_ptr dst, mpz_srcptr src, size_t n);
extern void	free_Q_vector (mpq_ptr p, size_t n);
extern void	free_Z_vector (mpz_ptr p, size_t n);
extern void	init_Q_vector (mpq_ptr p, size_t n);
extern void	init_Z_vector (mpz_ptr p, size_t n);
extern mpq_ptr	new_Q_vector (size_t n);
extern mpz_ptr	new_Z_vector (size_t n);
extern void	print_Q_vector (mpq_srcptr p, size_t n);
extern void	print_Z_vector (mpz_srcptr p, size_t n);

extern size_t	_mpz_bit_size (mpz_srcptr z);
extern size_t	_mpz_bit_size_vector (mpz_srcptr op, size_t n);
extern size_t	_mpq_bit_size (mpq_srcptr q);
extern size_t	_mpq_bit_size_vector (mpq_srcptr op, size_t n);

#endif
