/***********************************************************************

	$Id: qpdist2.h,v 1.1 2025/01/26 02:31:39 warme Exp $

	File:	qpdist2.h
	Rev:	a-1
	Date:	01/25/2025

	Copyright (c) 2012, 2025 by David M. Warme.  All rights
	reserved.  This work is licensed under a Creative Commons
	Attribution-NonCommercial-ShareAlike 4.0 International License.

************************************************************************

	Compute Centroid Distance (squared) via quadratic programming.

************************************************************************

	Modification Log:

	a-1:	01/25/2025	warme
		: Cleanup for initial release.

************************************************************************/

#ifndef QPDIST2_H
#define QPDIST2_H

#include "config.h"

#ifdef CPLEX

struct Constraint;
struct Polytope;

/*
 * An enumeration for selecting which flavor of Centroid Distance to
 * compute:
 *
 *	- Weak Centroid Distance	(affine hull)
 *	- Normal Centroid Distance	(convex hull)
 */

enum CD_Type {
	QPDIST2_WEAK_CD2,		/* Use affine hull */
	QPDIST2_NORMAL_CD2,		/* Use convex hull */
};

/*
 * Return the Centroid Distance squared for the given inequality with
 * respect to the given polytope.  This is a numeric approximation
 * (computed via quadratic programming), not an exact result.
 */

extern double	cd2_via_qp (const struct Constraint *	cp,
			    const struct Polytope *	poly,
			    enum CD_Type		cd_type);

#endif	/* CPLEX */

#endif
