/***********************************************************************

	File:	stgp_indicators.h
	Rev:	a-2
	Date:	01/25/2025

	Copyright (c) 1997, 2025 by David M. Warme

************************************************************************

	Compute strength indicators for polytope STGP(n) via
	closed-form formulae.

************************************************************************

	Modification Log:

	a-1:	11/07/2015	warme
		: Created.
	a-2:	01/25/2025	warme
		: Cleanup for initial release.

************************************************************************/

#ifndef STGP_INDICATORS_H
#define	STGP_INDICATORS_H

#include <gmp.h>

/*
 * Return the number of extreme points of STGP(n).
 */

extern void	stgp_num_extreme_points (mpz_ptr res, int n);

/*
 * Let e \in E.  Return the number of STHGP(n) extreme points that
 * contain edge e.
 */

extern void	stgp_num_edge_extreme_points (mpz_ptr res, int n);

/*
 * Return the number of STGP(n) extreme points incident to the
 * non-negativity inequality for some edge e.
 */

extern void	stgp_nonneg_ep_count (mpz_ptr		res,
				      int		n);

/*
 * Return the Extreme Point Ratio for an STGP(n) non-negativity inequality
 * for some edge e.
 */

extern void	stgp_nonneg_epr (mpq_ptr	res,
				 int		n);

/*
 * Return the Centroid Distance squared for an STGP(n) non-negativity
 * inequality for some edge e.
 */

extern void	stgp_nonneg_cd2 (mpq_ptr	res,
				 int		n);

/*
 * Return the number of STGP(n) extreme points incident to a
 * subtour inequality S of cardinality k.
 */

extern void	stgp_subtour_ep_count (mpz_ptr		res,
				       int		n,
				       int		k);

/*
 * Return the Extreme Point Ratio for an STGP(n) subtour S of cardinality k.
 */

extern void	stgp_subtour_epr (mpq_ptr	res,
				  int		n,
				  int		k);

/*
 * Return the Centroid Distance squared for an STGP(n) subtour S of
 * cardinality k.
 */

extern void	stgp_subtour_cd2 (mpq_ptr	res,
				  int		n,
				  int		k);

#endif
