/***********************************************************************

	File:	sthgp_sec_angles.h
	Rev:	a-2
	Date:	01/25/2025

	Copyright (c) 1997, 2025 by David M. Warme

************************************************************************

	Compute angle between a pair of STHGP(n) subtours via
	closed-form formulae.

************************************************************************

	Modification Log:

	a-1:	11/07/2015	warme
		: Created.
	a-2:	01/25/2025	warme
		: Cleanup for initial release.

************************************************************************/

#ifndef STHGP_SEC_ANGLES_H
#define	STHGP_SEC_ANGLES_H

#include <gmp.h>

/*
 * Return the angle (in *degrees*) between a pair of STHGP(n) subtours
 * S1 and S2:
 *
 *	n = total number of vertices
 *	p = number of vertices in S1 \ S2
 *	q = number of vertices in S2 \ S1
 *	r = number of vertices in S1 intersect S2
 */

extern double	sthgp_subtour_angle_theta (int n, int p, int q, int r);

/*
 * Return f(n,p,q,r): the cosine of the angle between normal vectors
 * N1 and N2 of STHGP(n) subtours S1 and S2:
 *
 *	n = total number of vertices
 *	p = number of vertices in S1 \ S2
 *	q = number of vertices in S2 \ S1
 *	r = number of vertices in S1 intersect S2
 */

extern double	sthgp_subtour_angle_f (
				int		n,
				int		p,
				int		q,
				int		r);

#endif
