/***********************************************************************

	File:	bitmaskmacros.c
	Rev:	a-2
	Date:	01/25/2025

	Copyright (c) 1997, 2025 by David M. Warme

************************************************************************

	Macros for efficient manipulation of bit masks.

************************************************************************

	Modification Log:

	a-1:	09/07/2015	warme
		: Created.
	a-2:	01/25/2025	warme
		: Cleanup for initial release.

************************************************************************/

#include "bitmaskmacros.h"

#include "logic.h"
#include "s3itypes.h"

#define	TABLE_SIZE	256

int8u		nbits [TABLE_SIZE];

/*
 * This routine initializes a translation table that converts an 8-bit
 * byte into the count of ONE bits in the byte.
 */

	void
init_nbits (void)

{
int		i;
int32u		bits;
int		count;

	for (i = 0; i < TABLE_SIZE; i++) {
		count = 0;
		for (bits = ((int32u) i); bits > 0; bits >>= 1) {
			if ((bits & 0x01) NE 0) {
				++count;
			}
		}
		nbits [i] = ((int8u) count);
	}
}
