/***********************************************************************

	File:	plot_sthgp_sec_angles.c
	Rev:	a-2
	Date:	01/25/2025

	Copyright (c) 1997, 2025 by David M. Warme

************************************************************************

	Generate data for various STHGP subtour angle plots.

************************************************************************

	Modification Log:

	a-1:	10/29/2023	warme
		: Created.
	a-2:	01/25/2025	warme
		: Cleanup for initial release.

************************************************************************/

#include "fatal.h"
#include <gmp.h>
#include "logic.h"
#include <math.h>
#include <mpfr.h>
#include <stdio.h>
#include <stdlib.h>
#include "sthgp_sec_angles.h"

/*
 * Global Data
 */

char *		me;

/*
 * Main routine.
 */

	int
main (

int		argc,
char **		argv
)
{
int		type, n, k;
double		frac_k, angle;

	me = argv [0];

	if (argc EQ 5) {
		int p, q, r;
		n = atoi (argv [1]);
		p = atoi (argv [2]);
		q = atoi (argv [3]);
		r = atoi (argv [4]);
		angle = sthgp_subtour_angle_theta (n, p, q, r);
		printf (" Theta (%d, %d, %d, %d) = %.17g degrees.\n",
			n, p, q, r, angle);
		exit (0);
	}

	if (argc NE 3) {
		fprintf (stderr,
			 "Usage: %s type N\n"
			 "  where type is:\n"
			 "\t0 = theta (n,k,n-k,0)\t(complementary)\n"
			 "\t1 = theta (n, 0, 1, k)\t(k vs k+1)\n"
			 "\t2 = theta (n, 0, k-2, 2)\t(2 vs k)\n"
			 "\t3 = theta (n, 0, n-1-k, k)\t(k vs n-1)\n"
			 "\t4 = theta (n, k, k, 0)\t(Independent k vs k)\n",
			 me);
		exit (1);
	}

	type = atoi (argv [1]);
	n = atoi (argv [2]);

	switch (type) {
	case 0:
		for (k = 2; k <= n - 2; k++) {
			angle = sthgp_subtour_angle_theta (n, k, n - k, 0);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 1:
		for (k = 2; k <= n - 2; k++) {
			angle = sthgp_subtour_angle_theta (n, 0, 1, k);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 2:
		for (k = 3; k <= n - 1; k++) {
			angle = sthgp_subtour_angle_theta (n, 0, k - 2, 2);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 3:
		for (k = 2; k <= n - 2; k++) {
			angle = sthgp_subtour_angle_theta (n, 0, n - k - 1, k);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 4:
		for (k = 2; 2 * k <= n; k++) {
			angle = sthgp_subtour_angle_theta (n, k, k, 0);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 5:
		for (k = 2; 2 * k <= n; k++) {
			angle = sthgp_subtour_angle_theta (n, 0, n - 2 * k, k);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 6:
		for (k = 2; 3 * k <= n; k++) {
			angle = sthgp_subtour_angle_theta (n, k, n - 3 * k, k);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	case 7:
		for (k = 2; 3 * k <= n; k++) {
			angle = sthgp_subtour_angle_theta (n, k, k, k);
			frac_k = k;
			frac_k /= n;
			printf ("%6.4f\t%.17g\n", frac_k, angle);
		}
		break;

	default:
		fprintf (stderr,
			 "%s: Invalid type %s\n", me, argv [1]);
		exit (1);
	}

	exit (0);
}
