/**********************************************************************

	$Id: primitive_combs.c,v 1.1 2025/01/26 02:31:52 warme Exp $

	File:	primitive_combs.c
	Rev:	a-1
	Date:	01/25/2025

	Copyright (c) 2012, 2025 by David M. Warme.  All rights
	reserved.  This work is licensed under a Creative Commons
	Attribution-NonCommercial-ShareAlike 4.0 International License.

***********************************************************************

	Count the number of TSP tours incident to each of the four
	most primitive possible 3-toothed comb inequalities.

***********************************************************************

	Modification Log:

	a-1:	01/25/2025	warme
		: Cleanup for initial release.

***********************************************************************/

#include "logic.h"
#include "new.h"
#include "polytope.h"
#include "s3itypes.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "tsp_polytope.h"

char *		me;

/*
 * Local Routines
 */

static void		count_combs_00 (void);
static void		count_combs_01 (void);
static void		count_combs_10 (void);
static void		count_combs_11 (void);

/*
 * The main program.
 */

	int
main (

int		argc,
char **		argv
)
{
	me = argv [0];

	count_combs_00 ();
	count_combs_01 ();
	count_combs_10 ();
	count_combs_11 ();

	exit (0);
}

/*
 * Count the number of tours satisfying a 3-toothed comb
 * wherein h = 0 and o = 0.
 */

	static
	void
count_combs_00 (void)

{
int			count;
struct Polytope *	poly;
struct IVecSet *	xpts;
struct Constraint *	cp;

	poly	= make_TSP_polytope (6);

	xpts	= poly -> get_extreme_points (poly);

	cp	= poly -> get_constraint (poly, "3comb-1-1-1-1-1-1-0");

	count	= get_extreme_points_incident_to_constraint (NULL, cp, xpts);

	printf ("h == 0, o == 0, count = %d\n", count);

	free_constraint_list (cp);
	free_incidence_vectors (xpts);
	poly -> free (poly);
}

/*
 * Count the number of tours satisfying a 3-toothed comb
 * wherein h = 0 and o >= 1.
 */

	static
	void
count_combs_01 (void)

{
int			count;
struct Polytope *	poly;
struct IVecSet *	xpts;
struct Constraint *	cp;

	poly	= make_TSP_polytope (7);

	xpts	= poly -> get_extreme_points (poly);

	cp	= poly -> get_constraint (poly, "3comb-1-1-1-1-1-1-0");

	count	= get_extreme_points_incident_to_constraint (NULL, cp, xpts);

	printf ("h == 0, o >= 0, count = %d\n", count);

	free_constraint_list (cp);
	free_incidence_vectors (xpts);
	poly -> free (poly);
}

/*
 * Count the number of tours satisfying a 3-toothed comb
 * wherein h >= 1 and o = 0.
 */

	static
	void
count_combs_10 (void)

{
int			count;
struct Polytope *	poly;
struct IVecSet *	xpts;
struct Constraint *	cp;

	poly	= make_TSP_polytope (7);

	xpts	= poly -> get_extreme_points (poly);

	cp	= poly -> get_constraint (poly, "3comb-1-1-1-1-1-1-1");

	count	= get_extreme_points_incident_to_constraint (NULL, cp, xpts);

	printf ("h >= 1, o == 0, count = %d\n", count);

	free_constraint_list (cp);
	free_incidence_vectors (xpts);
	poly -> free (poly);
}

/*
 * Count the number of tours satisfying a 3-toothed comb
 * wherein h >= 1 and o >= 1.
 */

	static
	void
count_combs_11 (void)

{
int			count;
struct Polytope *	poly;
struct IVecSet *	xpts;
struct Constraint *	cp;

	poly	= make_TSP_polytope (8);

	xpts	= poly -> get_extreme_points (poly);

	cp	= poly -> get_constraint (poly, "3comb-1-1-1-1-1-1-1");

	count	= get_extreme_points_incident_to_constraint (NULL, cp, xpts);

	printf ("h >= 1, o >= 1, count = %d\n", count);

	free_constraint_list (cp);
	free_incidence_vectors (xpts);
	poly -> free (poly);
}
