/**********************************************************************

	$Id: scale_y_to_one.c,v 1.2 2025/04/13 18:44:20 warme Exp $

	File:	scale_y_to_one.c
	Rev:	a-2
	Date:	04/13/2025

	Copyright (c) 2012, 2025 by David M. Warme.  All rights
	reserved.  This work is licensed under a Creative Commons
	Attribution-NonCommercial-ShareAlike 4.0 International License.

***********************************************************************

	Read in a sequence of (X,Y) coordinates, and scale the Y
	coordinates (which should all be non-negative) so that the
	maximum Y coordinate is 1.0.

***********************************************************************

	Modification Log:

	a-1:	01/25/2025	warme
		: Cleanup for initial release.
	a-2:	04/13/2025	warme
		: Force generated X coordinates to 3 decimal places.

***********************************************************************/

#include "fatal.h"
#include "logic.h"
#include <math.h>
#include "new.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>


/*
 * Global Routines
 */

int		main (int, char **);

char *		me;


/*
 * Local Types
 */

struct clist {
	double		x;
	double		y;
	struct clist *	next;
};

/*
 * The main routine.
 */

	int
main (

int		argc,
char **		argv
)
{
int			i;
struct clist *		root;
struct clist **		hookp;
struct clist *		p;
double			x, y, maxy;

	me = argv [0];

	/* Read in the coordinates. Compute max Y coord as we go. */
	maxy = -1.0;
	root = NULL;
	hookp = &root;
	for (;;) {
		i = scanf (" %lg %lg", &x, &y);
		if (i NE 2) break;

		FATAL_ERROR_IF (y < 0.0);

		if (y > maxy) {
			maxy = y;
		}

		p = NEW (struct clist);
		p -> x		= x;
		p -> y		= y;
		p -> next	= NULL;
		*hookp = p;
		hookp = &(p -> next);
	}

	FATAL_ERROR_IF (maxy <= 0.0);

	/* Echo the points with scaled Y coord. */
	for (p = root; p NE NULL; p = p -> next) {
		printf ("%.3g\t%.17g\n",
			p -> x, p -> y / maxy);
	}

	exit (0);
}
