#***********************************************************************
#
#	$Id: reflected_plots.gp,v 1.2 2025/04/13 18:44:28 warme Exp $
#
#	File:	reflected_plots.gp
#	Rev:	a-2
#	Date:	04/13/2025
#
#	Copyright (c) 2012, 2025 by David M. Warme.  All rights
#	reserved.  This work is licensed under a Creative Commons
#	Attribution-NonCommercial-ShareAlike 4.0 International License.
#
#***********************************************************************
#
#	Gnuplot script for reflected CD / EPR plots.
#
#***********************************************************************
#
#	Modification Log:
#
#	a-1:	01/25/2025	warme
#		: Cleanup for initial release.
#	a-2:	04/13/2025	warme
#		: Use two different data files for each plot so that
#		:  the "reflected" curve only covers k<=n/2.
#		: Add a legend to each plot.
#		: Increase font size.
#
#***********************************************************************

unset grid
set key at graph 0.6,0.2
# set nokey

# set xtics 0,0.1,1
# set ytics 0,0.2,1
# unset xtics
set xtics in ( "0" 0, "" 0.25, "" 0.5, "" 0.75, "n" 1.0 )
# unset ytics
set ytics in 0.0, 0.2, 1.0
set xrange [-0.05:1.05]
set yrange [-0.05:1.05]
# set title "Reflected Subtour Centroid Distances"
set xlabel "Subtour Size k"
set ylabel "Scaled Centroid Distance"

set term postscript color eps fontscale 1.75
set output "reflected_cd_color.eps"

plot	"sthgp_sec_dist_scaled_1000.dat" using 1:2 title "CD" with lines lc rgb "green" , \
	"reflected_cd.dat" using 1:2 title "Reflected CD" with lines lc rgb "red"

set term postscript eps monochrome dashed fontscale 1.75
set output "reflected_cd_mono.eps"

plot	"sthgp_sec_dist_scaled_1000.dat" using 1:2 title "CD" with lines ls 1, \
	"reflected_cd.dat" using 1:2 title "Reflected CD" with lines ls 2


unset grid
set key at graph 0.7,0.8
# set nokey

# unset xtics
set xtics in ( "0" 0, "" 0.25, "" 0.5, "" 0.75, "n" 1.0 )
# unset ytics
set ytics in -1.0, 0.2, 0.0
set xrange [-0.05:1.05]
set yrange [-1.05:0.05]
# set title "Reflected Subtour Extreme Point Ratios"
set xlabel "Subtour Size k"
set ylabel "Scaled log10 (Extreme Point ratio)"

set term postscript color eps fontscale 1.75
set output "reflected_epr_color.eps

plot	"sthgp_sec_ratio_scaled_1000.dat" using 1:2 title "EPR" with lines lc rgb "green", \
	"reflected_epr.dat" using 1:2 title "Reflected EPR" with lines lc rgb "red"


set term postscript eps monochrome dashed fontscale 1.75
set output "reflected_epr_mono.eps"

plot	"sthgp_sec_ratio_scaled_1000.dat" using 1:2 title "EPR" with lines ls 1, \
	"reflected_epr.dat" using 1:2 title "Reflected EPR" with lines ls 2
