#***********************************************************************
#
#	$Id: sthgp_dx.gp,v 1.2 2025/04/13 18:44:29 warme Exp $
#
#	File:	sthgp_dx.gp
#	Rev:	a-2
#	Date:	04/13/2025
#
#	Copyright (c) 2012, 2025 by David M. Warme.  All rights
#	reserved.  This work is licensed under a Creative Commons
#	Attribution-NonCommercial-ShareAlike 4.0 International License.
#
#***********************************************************************
#
#	Gnuplot script for STHGP CD dx plots.
#
#***********************************************************************
#
#	Modification Log:
#
#	a-1:	01/25/2025	warme
#		: Cleanup for initial release.
#	a-2:	04/13/2025	warme
#		: Add sthgp_dx_S_5_to_80 plots.
#		: Increase font size.
#
#***********************************************************************

# Generate all of the STHGP DX plots

# Color order: brown, orange, cyan, magenta, blue, green, red, black.

set xrange [-4:104]
set logscale y

set grid

set key bottom right

set xlabel "Subtour Cardinality k"
set ylabel "|Δx_e|"


set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_S_2_and_3_color.eps"

plot "sthgp_dx_S_3.dat" using 1:2 title "|e|=3" with lines lc rgbcolor "orange", \
     "sthgp_dx_S_2.dat" using 1:2 title "|e|=2" with lines lc rgbcolor "brown"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_S_2_and_3_mono.eps"

plot "sthgp_dx_S_3.dat" using 1:2 title "|e|=3" with lines ls 2, \
     "sthgp_dx_S_2.dat" using 1:2 title "|e|=2" with lines ls 1


set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_S_2_to_10_color.eps"

plot "sthgp_dx_S_10.dat" using 1:2 title "|e|=10" with lines lc rgbcolor "brown", \
     "sthgp_dx_S_9.dat"  using 1:2 title "|e|=9"  with lines lc rgbcolor "black", \
     "sthgp_dx_S_8.dat"  using 1:2 title "|e|=8"  with lines lc rgbcolor "red", \
     "sthgp_dx_S_7.dat"  using 1:2 title "|e|=7"  with lines lc rgbcolor "green", \
     "sthgp_dx_S_6.dat"  using 1:2 title "|e|=6"  with lines lc rgbcolor "blue", \
     "sthgp_dx_S_5.dat"  using 1:2 title "|e|=5"  with lines lc rgbcolor "magenta", \
     "sthgp_dx_S_4.dat"  using 1:2 title "|e|=4"  with lines lc rgbcolor "cyan", \
     "sthgp_dx_S_3.dat"  using 1:2 title "|e|=3"  with lines lc rgbcolor "orange", \
     "sthgp_dx_S_2.dat"  using 1:2 title "|e|=2"  with lines lc rgbcolor "brown"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_S_2_to_10_mono.eps"

plot "sthgp_dx_S_10.dat" using 1:2 title "|e|=10" with lines ls 9, \
     "sthgp_dx_S_9.dat"  using 1:2 title "|e|=9"  with lines ls 8, \
     "sthgp_dx_S_8.dat"  using 1:2 title "|e|=8"  with lines ls 7, \
     "sthgp_dx_S_7.dat"  using 1:2 title "|e|=7"  with lines ls 6, \
     "sthgp_dx_S_6.dat"  using 1:2 title "|e|=6"  with lines ls 5, \
     "sthgp_dx_S_5.dat"  using 1:2 title "|e|=5"  with lines ls 4, \
     "sthgp_dx_S_4.dat"  using 1:2 title "|e|=4"  with lines ls 3, \
     "sthgp_dx_S_3.dat"  using 1:2 title "|e|=3"  with lines ls 2, \
     "sthgp_dx_S_2.dat"  using 1:2 title "|e|=2"  with lines ls 1


set key top left

set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_S_2_to_80_color.eps"

plot "sthgp_dx_S_80.dat" using 1:2 title "|e|=80" with lines lc rgbcolor "brown", \
     "sthgp_dx_S_50.dat" using 1:2 title "|e|=50" with lines lc rgbcolor "black", \
     "sthgp_dx_S_20.dat" using 1:2 title "|e|=20" with lines lc rgbcolor "red", \
     "sthgp_dx_S_10.dat" using 1:2 title "|e|=10" with lines lc rgbcolor "green", \
     "sthgp_dx_S_5.dat"  using 1:2 title "|e|=5"  with lines lc rgbcolor "blue", \
     "sthgp_dx_S_2.dat"  using 1:2 title "|e|=2"  with lines lc rgbcolor "magenta"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_S_2_to_80_mono.eps"

plot "sthgp_dx_S_80.dat" using 1:2 title "|e|=80" with lines ls 9, \
     "sthgp_dx_S_50.dat" using 1:2 title "|e|=50" with lines ls 8, \
     "sthgp_dx_S_20.dat" using 1:2 title "|e|=20" with lines ls 7, \
     "sthgp_dx_S_10.dat" using 1:2 title "|e|=10" with lines ls 6, \
     "sthgp_dx_S_5.dat"  using 1:2 title "|e|=5"  with lines ls 5, \
     "sthgp_dx_S_2.dat"  using 1:2 title "|e|=2"  with lines ls 4

set key top left

set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_S_5_to_80_color.eps"

plot "sthgp_dx_S_80.dat" using 1:2 title "|e|=80" with lines lc rgbcolor "brown", \
     "sthgp_dx_S_50.dat" using 1:2 title "|e|=50" with lines lc rgbcolor "black", \
     "sthgp_dx_S_20.dat" using 1:2 title "|e|=20" with lines lc rgbcolor "red", \
     "sthgp_dx_S_10.dat" using 1:2 title "|e|=10" with lines lc rgbcolor "green", \
     "sthgp_dx_S_5.dat"  using 1:2 title "|e|=5"  with lines lc rgbcolor "blue"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_S_5_to_80_mono.eps"

plot "sthgp_dx_S_80.dat" using 1:2 title "|e|=80" with lines ls 9, \
     "sthgp_dx_S_50.dat" using 1:2 title "|e|=50" with lines ls 8, \
     "sthgp_dx_S_20.dat" using 1:2 title "|e|=20" with lines ls 7, \
     "sthgp_dx_S_10.dat" using 1:2 title "|e|=10" with lines ls 6, \
     "sthgp_dx_S_5.dat"  using 1:2 title "|e|=5"  with lines ls 5


set key bottom right

set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_0_2_to_80_color.eps"

plot "sthgp_dx_0_80.dat" using 1:2 title "|e|=80" with lines lc rgbcolor "brown", \
     "sthgp_dx_0_50.dat" using 1:2 title "|e|=50" with lines lc rgbcolor "black", \
     "sthgp_dx_0_20.dat" using 1:2 title "|e|=20" with lines lc rgbcolor "red", \
     "sthgp_dx_0_10.dat" using 1:2 title "|e|=10" with lines lc rgbcolor "green", \
     "sthgp_dx_0_5.dat"  using 1:2 title "|e|=5"  with lines lc rgbcolor "blue", \
     "sthgp_dx_0_2.dat"  using 1:2 title "|e|=2"  with lines lc rgbcolor "magenta"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_0_2_to_80_mono.eps"

plot "sthgp_dx_0_80.dat" using 1:2 title "|e|=80" with lines ls 9, \
     "sthgp_dx_0_50.dat" using 1:2 title "|e|=50" with lines ls 8, \
     "sthgp_dx_0_20.dat" using 1:2 title "|e|=20" with lines ls 7, \
     "sthgp_dx_0_10.dat" using 1:2 title "|e|=10" with lines ls 6, \
     "sthgp_dx_0_5.dat"  using 1:2 title "|e|=5"  with lines ls 5, \
     "sthgp_dx_0_2.dat"  using 1:2 title "|e|=2"  with lines ls 4


set key bottom right

set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_1_2_to_80_color.eps"

plot "sthgp_dx_1_80.dat" using 1:2 title "|e|=80" with lines lc rgbcolor "brown", \
     "sthgp_dx_1_50.dat" using 1:2 title "|e|=50" with lines lc rgbcolor "black", \
     "sthgp_dx_1_20.dat" using 1:2 title "|e|=20" with lines lc rgbcolor "red", \
     "sthgp_dx_1_10.dat" using 1:2 title "|e|=10" with lines lc rgbcolor "green", \
     "sthgp_dx_1_5.dat"  using 1:2 title "|e|=5"  with lines lc rgbcolor "blue", \
     "sthgp_dx_1_2.dat"  using 1:2 title "|e|=2"  with lines lc rgbcolor "magenta"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_1_2_to_80_mono.eps"

plot "sthgp_dx_1_80.dat" using 1:2 title "|e|=80" with lines ls 9, \
     "sthgp_dx_1_50.dat" using 1:2 title "|e|=50" with lines ls 8, \
     "sthgp_dx_1_20.dat" using 1:2 title "|e|=20" with lines ls 7, \
     "sthgp_dx_1_10.dat" using 1:2 title "|e|=10" with lines ls 6, \
     "sthgp_dx_1_5.dat"  using 1:2 title "|e|=5"  with lines ls 5, \
     "sthgp_dx_1_2.dat"  using 1:2 title "|e|=2"  with lines ls 4


set key bottom left

set term postscript eps color solid fontscale 1.75
set output "sthgp_dx_sums_color.eps"

plot "sthgp_dx_sums.dat" using 1:2 title "Σ e in E(S)"   with lines lc rgbcolor "green", \
     "sthgp_dx_sums.dat" using 1:3 title "Σ e in E-E(S)" with lines lc rgbcolor "magenta"

set term postscript eps mono dashed fontscale 1.75
set output "sthgp_dx_sums_mono.eps"

plot "sthgp_dx_sums.dat" using 1:2 title "Σ e in E(S)"   with lines ls 2, \
     "sthgp_dx_sums.dat" using 1:3 title "Σ e in E-E(S)" with lines ls 1
