#***********************************************************************
#
#	$Id: sthgp_sec_dist_scaled.gp,v 1.2 2025/04/13 18:44:29 warme Exp $
#
#	File:	sthgp_sec_dist_scaled.gp
#	Rev:	a-2
#	Date:	04/13/2025
#
#	Copyright (c) 2012, 2025 by David M. Warme.  All rights
#	reserved.  This work is licensed under a Creative Commons
#	Attribution-NonCommercial-ShareAlike 4.0 International License.
#
#***********************************************************************
#
#	Gnuplot script for scaled STHGP subtour CD plots.
#
#***********************************************************************
#
#	Modification Log:
#
#	a-1:	01/25/2025	warme
#		: Cleanup for initial release.
#	a-2:	04/13/2025	warme
#		: Increase font size.
#
#***********************************************************************

# Plot STHGP subtour facet centroid distances in scaled fashion.

set xrange [-0.05:1.05]
set yrange [-0.05:1.05]
# set key rmargin
unset key

set xlabel "Subtour Size k"
set ylabel "Scaled Centroid Distance"

# unset ytics
set xtics out
set xtics in
set xtics ( "0" 0.0, "" 0.25, "" 0.5, "" 0.75, "n" 1.0 )

set term postscript eps color solid fontscale 1.75

set output "sthgp_sec_dist_scaled_0010_color.eps"
plot "sthgp_sec_dist_scaled_0010.dat" using 1:2 with lines lc rgbcolor "brown"

set output "sthgp_sec_dist_scaled_0020_color.eps"
plot "sthgp_sec_dist_scaled_0020.dat" using 1:2 with lines lc rgbcolor "orange"

set output "sthgp_sec_dist_scaled_0050_color.eps"
plot "sthgp_sec_dist_scaled_0050.dat" using 1:2 with lines lc rgbcolor "cyan"

set output "sthgp_sec_dist_scaled_0100_color.eps"
plot "sthgp_sec_dist_scaled_0100.dat" using 1:2 with lines lc rgbcolor "magenta"

set output "sthgp_sec_dist_scaled_0200_color.eps"
plot "sthgp_sec_dist_scaled_0200.dat" using 1:2 with lines lc rgbcolor "blue"

set output "sthgp_sec_dist_scaled_0500_color.eps"
plot "sthgp_sec_dist_scaled_0500.dat" using 1:2 with lines lc rgbcolor "green"

set output "sthgp_sec_dist_scaled_1000_color.eps"
plot "sthgp_sec_dist_scaled_1000.dat" using 1:2 with lines lc rgbcolor "red"


set key rmargin
set output "sthgp_sec_dist_scaled_all_color.eps"

plot "sthgp_sec_dist_scaled_0010.dat" using 1:2 title "n=10"   with lines lc rgbcolor "brown", \
     "sthgp_sec_dist_scaled_0020.dat" using 1:2 title "n=20"   with lines lc rgbcolor "orange", \
     "sthgp_sec_dist_scaled_0050.dat" using 1:2 title "n=50"   with lines lc rgbcolor "cyan", \
     "sthgp_sec_dist_scaled_0100.dat" using 1:2 title "n=100"  with lines lc rgbcolor "magenta", \
     "sthgp_sec_dist_scaled_0200.dat" using 1:2 title "n=200"  with lines lc rgbcolor "blue", \
     "sthgp_sec_dist_scaled_0500.dat" using 1:2 title "n=500"  with lines lc rgbcolor "green", \
     "sthgp_sec_dist_scaled_1000.dat" using 1:2 title "n=1000" with lines lc rgbcolor "red"

unset key

set term postscript eps monochrome dashed fontscale 1.75

set output "sthgp_sec_dist_scaled_0010_mono.eps"
plot "sthgp_sec_dist_scaled_0010.dat" using 1:2 with lines ls 8

set output "sthgp_sec_dist_scaled_0020_mono.eps"
plot "sthgp_sec_dist_scaled_0020.dat" using 1:2 with lines ls 7

set output "sthgp_sec_dist_scaled_0050_mono.eps"
plot "sthgp_sec_dist_scaled_0050.dat" using 1:2 with lines ls 5

set output "sthgp_sec_dist_scaled_0100_mono.eps"
plot "sthgp_sec_dist_scaled_0100.dat" using 1:2 with lines ls 4

set output "sthgp_sec_dist_scaled_0200_mono.eps"
plot "sthgp_sec_dist_scaled_0200.dat" using 1:2 with lines ls 3

set output "sthgp_sec_dist_scaled_0500_mono.eps"
plot "sthgp_sec_dist_scaled_0500.dat" using 1:2 with lines ls 2

set output "sthgp_sec_dist_scaled_1000_mono.eps"
plot "sthgp_sec_dist_scaled_1000.dat" using 1:2 with lines ls 1


set key rmargin

set output "sthgp_sec_dist_scaled_all_mono.eps"

plot "sthgp_sec_dist_scaled_0010.dat" using 1:2 title "n=10"   with lines ls 8, \
     "sthgp_sec_dist_scaled_0020.dat" using 1:2 title "n=20"   with lines ls 7, \
     "sthgp_sec_dist_scaled_0050.dat" using 1:2 title "n=50"   with lines ls 5, \
     "sthgp_sec_dist_scaled_0100.dat" using 1:2 title "n=100"  with lines ls 4, \
     "sthgp_sec_dist_scaled_0200.dat" using 1:2 title "n=200"  with lines ls 3, \
     "sthgp_sec_dist_scaled_0500.dat" using 1:2 title "n=500"  with lines ls 2, \
     "sthgp_sec_dist_scaled_1000.dat" using 1:2 title "n=1000" with lines ls 1
