#***********************************************************************
#
#	$Id: tsp_sec_ratio.gp,v 1.2 2025/04/13 18:44:29 warme Exp $
#
#	File:	tsp_sec_ratio.gp
#	Rev:	a-2
#	Date:	04/13/2025
#
#	Copyright (c) 2012, 2025 by David M. Warme.  All rights
#	reserved.  This work is licensed under a Creative Commons
#	Attribution-NonCommercial-ShareAlike 4.0 International License.
#
#***********************************************************************
#
#	Gnuplot script for TSP subtour EPR plots.
#
#***********************************************************************
#
#	Modification Log:
#
#	a-1:	01/25/2025	warme
#		: Cleanup for initial release.
#	a-2:	04/13/2025	warme
#		: Increase font size.
#
#***********************************************************************

# Plot TSP subtour facet extreme point ratios.

set xrange [-0.05:1.05]
set key rmargin

set xlabel "Subtour Size k"
set ylabel "log10(Extreme Point Ratio)"

set xtics out
set xtics in
set xtics ( "0" 0.0, "" 0.25, "" 0.5, "" 0.75, "n" 1.0 )

set term postscript eps color solid fontscale 1.75
set output "tsp_sec_ratio_all_color.eps"

plot "tsp_sec_ratio_0010.dat" using 1:2 title "n=10"   with lines lc rgbcolor "brown", \
     "tsp_sec_ratio_0020.dat" using 1:2 title "n=20"   with lines lc rgbcolor "orange", \
     "tsp_sec_ratio_0050.dat" using 1:2 title "n=50"   with lines lc rgbcolor "cyan", \
     "tsp_sec_ratio_0100.dat" using 1:2 title "n=100"  with lines lc rgbcolor "magenta", \
     "tsp_sec_ratio_0200.dat" using 1:2 title "n=200"  with lines lc rgbcolor "blue", \
     "tsp_sec_ratio_0500.dat" using 1:2 title "n=500"  with lines lc rgbcolor "green", \
     "tsp_sec_ratio_1000.dat" using 1:2 title "n=1000" with lines lc rgbcolor "red"

set output "tsp_sec_ratio_detail_color.eps"

plot "tsp_sec_ratio_0010.dat" using 1:2 title "n=10"   with lines lc rgbcolor "brown", \
     "tsp_sec_ratio_0020.dat" using 1:2 title "n=20"   with lines lc rgbcolor "orange", \
     "tsp_sec_ratio_0050.dat" using 1:2 title "n=50"   with lines lc rgbcolor "cyan", \
     "tsp_sec_ratio_0100.dat" using 1:2 title "n=100"  with lines lc rgbcolor "magenta"

set term postscript eps monochrome dashed fontscale 1.75
set output "tsp_sec_ratio_all_mono.eps"

plot "tsp_sec_ratio_0010.dat" using 1:2 title "n=10"   with lines ls 8, \
     "tsp_sec_ratio_0020.dat" using 1:2 title "n=20"   with lines ls 7, \
     "tsp_sec_ratio_0050.dat" using 1:2 title "n=50"   with lines ls 5, \
     "tsp_sec_ratio_0100.dat" using 1:2 title "n=100"  with lines ls 4, \
     "tsp_sec_ratio_0200.dat" using 1:2 title "n=200"  with lines ls 3, \
     "tsp_sec_ratio_0500.dat" using 1:2 title "n=500"  with lines ls 2, \
     "tsp_sec_ratio_1000.dat" using 1:2 title "n=1000" with lines ls 1

set output "tsp_sec_ratio_detail_mono.eps"

plot "tsp_sec_ratio_0010.dat" using 1:2 title "n=10"   with lines ls 8, \
     "tsp_sec_ratio_0020.dat" using 1:2 title "n=20"   with lines ls 7, \
     "tsp_sec_ratio_0050.dat" using 1:2 title "n=50"   with lines ls 5, \
     "tsp_sec_ratio_0100.dat" using 1:2 title "n=100"  with lines ls 4
